@@ -21,7 +21,7 @@ cached_file = "cogram_server.json"
 
 debug_mode = os.getenv("DEBUG_MODE", "false") == "true"
 
-backend_url = os.getenv("BACKEND_URL", "https://api.cogram.ai")
+backend_url = os.getenv("BACKEND_URL", "https://api.cogram.com")
 
 DEFAULT_CDN_PATHS = [
     {
@@ -108,7 +108,7 @@ def import_cogram_server() -> Any:
         return import_from_url(
             cdn_urls[0]["source_url"],
             "jupyter_cogram_serverextension",
-            version="0.11.15",
+            version="0.11.16",
         )
 
     latest_version = get_latest_version(cdn_urls[0]["metadata_url"])
